@@ -195,6 +195,7 @@ col_vals_between <- function(x,
                              preconditions = NULL,
                              actions = NULL,
                              step_id = NULL,
+                             label = NULL,
                              brief = NULL,
                              active = TRUE) {
   
@@ -217,6 +218,7 @@ col_vals_between <- function(x,
         inclusive = inclusive,
         na_pass = na_pass,
         preconditions = preconditions,
+        label = label,
         brief = brief,
         actions = prime_actions(actions),
         active = active
@@ -252,6 +254,7 @@ col_vals_between <- function(x,
         preconditions = preconditions,
         actions = covert_actions(actions, agent),
         step_id = step_id[i],
+        label = label,
         brief = brief[i],
         active = active
       )
