@@ -149,6 +149,7 @@ col_vals_equal <- function(x,
                            preconditions = NULL,
                            actions = NULL,
                            step_id = NULL,
+                           label = NULL,
                            brief = NULL,
                            active = TRUE) {
   
@@ -166,6 +167,7 @@ col_vals_equal <- function(x,
         value = value,
         na_pass = na_pass,
         preconditions = preconditions,
+        label = label,
         brief = brief,
         actions = prime_actions(actions),
         active = active
@@ -201,6 +203,7 @@ col_vals_equal <- function(x,
         preconditions = preconditions,
         actions = covert_actions(actions, agent),
         step_id = step_id[i],
+        label = label,
         brief = brief[i],
         active = active
       )
