@@ -151,6 +151,7 @@ col_vals_lt <- function(x,
                         preconditions = NULL,
                         actions = NULL,
                         step_id = NULL,
+                        label = NULL,
                         brief = NULL,
                         active = TRUE) {
   
@@ -168,6 +169,7 @@ col_vals_lt <- function(x,
         value = value,
         na_pass = na_pass,
         preconditions = preconditions,
+        label = label,
         brief = brief,
         actions = prime_actions(actions),
         active = active
@@ -203,6 +205,7 @@ col_vals_lt <- function(x,
         preconditions = preconditions,
         actions = covert_actions(actions, agent),
         step_id = step_id[i],
+        label = label,
         brief = brief[i],
         active = active
       )
