@@ -144,6 +144,7 @@ col_vals_not_in_set <- function(x,
                                 preconditions = NULL,
                                 actions = NULL,
                                 step_id = NULL,
+                                label = NULL,
                                 brief = NULL,
                                 active = TRUE) {
   
@@ -160,6 +161,7 @@ col_vals_not_in_set <- function(x,
         columns = columns,
         set = set,
         preconditions = preconditions,
+        label = label,
         brief = brief,
         actions = prime_actions(actions),
         active = active
@@ -194,6 +196,7 @@ col_vals_not_in_set <- function(x,
         preconditions = preconditions,
         actions = covert_actions(actions, agent),
         step_id = step_id[i],
+        label = label,
         brief = brief[i],
         active = active
       )
