@@ -140,6 +140,7 @@ col_vals_not_null <- function(x,
                               preconditions = NULL,
                               actions = NULL,
                               step_id = NULL,
+                              label = NULL,
                               brief = NULL,
                               active = TRUE) {
   
@@ -157,6 +158,7 @@ col_vals_not_null <- function(x,
       col_vals_not_null(
         columns = columns,
         preconditions = preconditions,
+        label = label,
         brief = brief,
         actions = prime_actions(actions),
         active = active
@@ -190,6 +192,7 @@ col_vals_not_null <- function(x,
         preconditions = preconditions,
         actions = covert_actions(actions, agent),
         step_id = step_id[i],
+        label = label,
         brief = brief[i],
         active = active
       )
