@@ -23,14 +23,14 @@
 #' `scan_data(tbl = mtcars) %>% as.character()`). The resulting HTML string is a
 #' complete HTML document where Bootstrap and jQuery are embedded within.
 #' 
-#' @param tbl The input table. This can be a data frame, tibble, or `tbl_dbi`.
-#'   object.
+#' @param tbl The input table. This can be a data frame, tibble, a `tbl_dbi`
+#'   object, or a `tbl_spark` object.
 #' @param sections The sections to include in the finalized `Table Scan` report.
 #'   A character vector with section names is required here. The sections in
 #'   their default order are: `"overview"`, `"variables"`, `"interactions"`,
 #'   `"correlations"`, `"missing"`, and `"sample"`. This vector can be comprised
 #'   of less elements and the order can be changed to suit the desired layout of
-#'   the report. For `tbl_dbi` objects, the `"interactions"` and
+#'   the report. For `tbl_dbi` and `tbl_spark` objects, the `"interactions"` and
 #'   `"correlations"` sections are excluded.
 #' @param navbar Should there be a navigation bar anchored to the top of the
 #'   report page? By default this is `TRUE`.
@@ -57,7 +57,7 @@ scan_data <- function(tbl,
   # nocov start
   
   # Limit components if a `tbl_dbi` object is supplied as the `tbl`
-  if (inherits(tbl, "tbl_dbi")) {
+  if (inherits(tbl, "tbl_dbi") || inherits(tbl, "tbl_spark")) {
     sections <- setdiff(sections, c("interactions", "correlations"))
   }
   
