@@ -6,6 +6,7 @@ create_validation_step <- function(agent,
                                    preconditions = NULL,
                                    actions = NULL,
                                    step_id = NULL,
+                                   label = NULL,
                                    brief = NULL,
                                    active = NULL) {
   
@@ -40,6 +41,7 @@ create_validation_step <- function(agent,
       na_pass = ifelse(is.null(na_pass), as.logical(NA), as.logical(na_pass)),
       preconditions = ifelse(is.null(preconditions), list(NULL), list(preconditions)),
       actions = ifelse(is.null(actions), list(NULL), list(actions)),
+      label = ifelse(is.null(label), NA_character_, as.character(label)),
       brief = ifelse(is.null(brief), NA_character_, as.character(brief)),
       active = ifelse(is.null(active), NA, active),
       eval_error = NA,
