@@ -18,8 +18,7 @@ test_that("Creating a `col_is_character()` step is possible", {
   expect_equivalent(validation$col_names, c("date_time", "date", "a", "b", "c", "d", "e", "f"))
   expect_equivalent(validation$validation_set$assertion_type, "col_is_character")
   expect_equivalent(validation$validation_set$column, "b")
-  expect_true(is.na(validation$validation_set$value))
-  expect_true(is.na(validation$validation_set$regex))
+  expect_true(is.null(validation$validation_set[["values"]][[1]]))
   expect_true(is.na(validation$validation_set$all_passed))
   expect_true(is.na(validation$validation_set$n))
   expect_true(is.na(validation$validation_set$n_passed))
@@ -63,8 +62,7 @@ test_that("Creating a `col_is_date()` step is possible", {
   expect_equivalent(validation$col_names, c("date_time", "date", "a", "b", "c", "d", "e", "f"))
   expect_equivalent(validation$validation_set$assertion_type, "col_is_date")
   expect_equivalent(validation$validation_set$column, "b")
-  expect_true(is.na(validation$validation_set$value))
-  expect_true(is.na(validation$validation_set$regex))
+  expect_true(is.null(validation$validation_set[["values"]][[1]]))
   expect_true(is.na(validation$validation_set$all_passed))
   expect_true(is.na(validation$validation_set$n))
   expect_true(is.na(validation$validation_set$n_passed))
@@ -108,8 +106,7 @@ test_that("Creating a `col_is_factor()` step is possible", {
   expect_equivalent(validation$col_names, c("date_time", "date", "a", "b", "c", "d", "e", "f"))
   expect_equivalent(validation$validation_set$assertion_type, "col_is_factor")
   expect_equivalent(validation$validation_set$column, "b")
-  expect_true(is.na(validation$validation_set$value))
-  expect_true(is.na(validation$validation_set$regex))
+  expect_true(is.null(validation$validation_set[["values"]][[1]]))
   expect_true(is.na(validation$validation_set$all_passed))
   expect_true(is.na(validation$validation_set$n))
   expect_true(is.na(validation$validation_set$n_passed))
@@ -153,8 +150,7 @@ test_that("Creating a `col_is_integer()` step is possible", {
   expect_equivalent(validation$col_names, c("date_time", "date", "a", "b", "c", "d", "e", "f"))
   expect_equivalent(validation$validation_set$assertion_type, "col_is_integer")
   expect_equivalent(validation$validation_set$column, "b")
-  expect_true(is.na(validation$validation_set$value))
-  expect_true(is.na(validation$validation_set$regex))
+  expect_true(is.null(validation$validation_set[["values"]][[1]]))
   expect_true(is.na(validation$validation_set$all_passed))
   expect_true(is.na(validation$validation_set$n))
   expect_true(is.na(validation$validation_set$n_passed))
@@ -198,8 +194,7 @@ test_that("Creating a `col_is_logical()` step is possible", {
   expect_equivalent(validation$col_names, c("date_time", "date", "a", "b", "c", "d", "e", "f"))
   expect_equivalent(validation$validation_set$assertion_type, "col_is_logical")
   expect_equivalent(validation$validation_set$column, "b")
-  expect_true(is.na(validation$validation_set$value))
-  expect_true(is.na(validation$validation_set$regex))
+  expect_true(is.null(validation$validation_set[["values"]][[1]]))
   expect_true(is.na(validation$validation_set$all_passed))
   expect_true(is.na(validation$validation_set$n))
   expect_true(is.na(validation$validation_set$n_passed))
@@ -243,8 +238,7 @@ test_that("Creating a `col_is_numeric()` step is possible", {
   expect_equivalent(validation$col_names, c("date_time", "date", "a", "b", "c", "d", "e", "f"))
   expect_equivalent(validation$validation_set$assertion_type, "col_is_numeric")
   expect_equivalent(validation$validation_set$column, "b")
-  expect_true(is.na(validation$validation_set$value))
-  expect_true(is.na(validation$validation_set$regex))
+  expect_true(is.null(validation$validation_set[["values"]][[1]]))
   expect_true(is.na(validation$validation_set$all_passed))
   expect_true(is.na(validation$validation_set$n))
   expect_true(is.na(validation$validation_set$n_passed))
@@ -288,8 +282,7 @@ test_that("Creating a `col_is_posix()` step is possible", {
   expect_equivalent(validation$col_names, c("date_time", "date", "a", "b", "c", "d", "e", "f"))
   expect_equivalent(validation$validation_set$assertion_type, "col_is_posix")
   expect_equivalent(validation$validation_set$column, "b")
-  expect_true(is.na(validation$validation_set$value))
-  expect_true(is.na(validation$validation_set$regex))
+  expect_true(is.null(validation$validation_set[["values"]][[1]]))
   expect_true(is.na(validation$validation_set$all_passed))
   expect_true(is.na(validation$validation_set$n))
   expect_true(is.na(validation$validation_set$n_passed))
@@ -333,9 +326,7 @@ test_that("Creating a `col_vals_between()` step is possible", {
   expect_equivalent(validation$col_names, c("date_time", "date", "a", "b", "c", "d", "e", "f"))
   expect_equivalent(validation$validation_set$assertion_type, "col_vals_between")
   expect_equivalent(validation$validation_set$column, "b")
-  expect_true(is.na(validation$validation_set$value))
-  expect_equivalent(validation$validation_set[["set"]] %>% unlist(), c(2, 10))
-  expect_true(is.na(validation$validation_set$regex))
+  expect_equivalent(validation$validation_set[["values"]] %>% unlist(), c(2, 10))
   expect_true(is.na(validation$validation_set$all_passed))
   expect_true(is.na(validation$validation_set$n))
   expect_true(is.na(validation$validation_set$n_passed))
@@ -379,9 +370,7 @@ test_that("Creating a `col_vals_not_between()` step is possible", {
   expect_equivalent(validation$col_names, c("date_time", "date", "a", "b", "c", "d", "e", "f"))
   expect_equivalent(validation$validation_set$assertion_type, "col_vals_not_between")
   expect_equivalent(validation$validation_set$column, "b")
-  expect_true(is.na(validation$validation_set$value))
-  expect_equivalent(validation$validation_set[["set"]] %>% unlist(), c(2, 10))
-  expect_true(is.na(validation$validation_set$regex))
+  expect_equivalent(validation$validation_set[["values"]] %>% unlist(), c(2, 10))
   expect_true(is.na(validation$validation_set$all_passed))
   expect_true(is.na(validation$validation_set$n))
   expect_true(is.na(validation$validation_set$n_passed))
@@ -425,8 +414,7 @@ test_that("Creating a `col_vals_equal()` step is possible", {
   expect_equivalent(validation$col_names, c("date_time", "date", "a", "b", "c", "d", "e", "f"))
   expect_equivalent(validation$validation_set$assertion_type, "col_vals_equal")
   expect_equivalent(validation$validation_set$column, "b")
-  expect_equivalent(validation$validation_set$value, 5)
-  expect_true(is.na(validation$validation_set$regex))
+  expect_equivalent(validation$validation_set[["values"]] %>% unlist(), 5)
   expect_true(is.na(validation$validation_set$all_passed))
   expect_true(is.na(validation$validation_set$n))
   expect_true(is.na(validation$validation_set$n_passed))
@@ -470,8 +458,7 @@ test_that("Creating a `col_vals_not_equal()` step is possible", {
   expect_equivalent(validation$col_names, c("date_time", "date", "a", "b", "c", "d", "e", "f"))
   expect_equivalent(validation$validation_set$assertion_type, "col_vals_not_equal")
   expect_equivalent(validation$validation_set$column, "b")
-  expect_equivalent(validation$validation_set$value, 5)
-  expect_true(is.na(validation$validation_set$regex))
+  expect_equivalent(validation$validation_set[["values"]] %>% unlist(), 5)
   expect_true(is.na(validation$validation_set$all_passed))
   expect_true(is.na(validation$validation_set$n))
   expect_true(is.na(validation$validation_set$n_passed))
@@ -515,8 +502,7 @@ test_that("Creating a `col_vals_gt()` step is possible", {
   expect_equivalent(validation$col_names, c("date_time", "date", "a", "b", "c", "d", "e", "f"))
   expect_equivalent(validation$validation_set$assertion_type, "col_vals_gt")
   expect_equivalent(validation$validation_set$column, "b")
-  expect_equivalent(validation$validation_set$value, 5)
-  expect_true(is.na(validation$validation_set$regex))
+  expect_equivalent(validation$validation_set[["values"]] %>% unlist(), 5)
   expect_true(is.na(validation$validation_set$all_passed))
   expect_true(is.na(validation$validation_set$n))
   expect_true(is.na(validation$validation_set$n_passed))
@@ -560,8 +546,7 @@ test_that("Creating a `col_vals_gte()` step is possible", {
   expect_equivalent(validation$col_names, c("date_time", "date", "a", "b", "c", "d", "e", "f"))
   expect_equivalent(validation$validation_set$assertion_type, "col_vals_gte")
   expect_equivalent(validation$validation_set$column, "b")
-  expect_equivalent(validation$validation_set$value, 5)
-  expect_true(is.na(validation$validation_set$regex))
+  expect_equivalent(validation$validation_set[["values"]] %>% unlist(), 5)
   expect_true(is.na(validation$validation_set$all_passed))
   expect_true(is.na(validation$validation_set$n))
   expect_true(is.na(validation$validation_set$n_passed))
@@ -605,8 +590,7 @@ test_that("Creating a `col_vals_lt()` step is possible", {
   expect_equivalent(validation$col_names, c("date_time", "date", "a", "b", "c", "d", "e", "f"))
   expect_equivalent(validation$validation_set$assertion_type, "col_vals_lt")
   expect_equivalent(validation$validation_set$column, "b")
-  expect_equivalent(validation$validation_set$value, 5)
-  expect_true(is.na(validation$validation_set$regex))
+  expect_equivalent(validation$validation_set[["values"]] %>% unlist(), 5)
   expect_true(is.na(validation$validation_set$all_passed))
   expect_true(is.na(validation$validation_set$n))
   expect_true(is.na(validation$validation_set$n_passed))
@@ -650,8 +634,7 @@ test_that("Creating a `col_vals_lte()` step is possible", {
   expect_equivalent(validation$col_names, c("date_time", "date", "a", "b", "c", "d", "e", "f"))
   expect_equivalent(validation$validation_set$assertion_type, "col_vals_lte")
   expect_equivalent(validation$validation_set$column, "b")
-  expect_equivalent(validation$validation_set$value, 5)
-  expect_true(is.na(validation$validation_set$regex))
+  expect_equivalent(validation$validation_set[["values"]] %>% unlist(), 5)
   expect_true(is.na(validation$validation_set$all_passed))
   expect_true(is.na(validation$validation_set$n))
   expect_true(is.na(validation$validation_set$n_passed))
@@ -695,9 +678,7 @@ test_that("Creating a `col_vals_in_set()` step is possible", {
   expect_equivalent(validation$col_names, c("date_time", "date", "a", "b", "c", "d", "e", "f"))
   expect_equivalent(validation$validation_set$assertion_type, "col_vals_in_set")
   expect_equivalent(validation$validation_set$column, "b")
-  expect_true(is.na(validation$validation_set$value))
-  expect_equivalent(validation$validation_set[["set"]] %>% unlist(), c("1-bcd-345", "5-jdo-903"))
-  expect_true(is.na(validation$validation_set$regex))
+  expect_equivalent(validation$validation_set[["values"]] %>% unlist(), c("1-bcd-345", "5-jdo-903"))
   expect_true(is.na(validation$validation_set$all_passed))
   expect_true(is.na(validation$validation_set$n))
   expect_true(is.na(validation$validation_set$n_passed))
@@ -741,9 +722,7 @@ test_that("Creating a `col_vals_not_in_set()` step is possible", {
   expect_equivalent(validation$col_names, c("date_time", "date", "a", "b", "c", "d", "e", "f"))
   expect_equivalent(validation$validation_set$assertion_type, "col_vals_not_in_set")
   expect_equivalent(validation$validation_set$column, "b")
-  expect_true(is.na(validation$validation_set$value))
-  expect_equivalent(validation$validation_set[["set"]] %>% unlist(), c("1-bcd-345", "5-jdo-903"))
-  expect_true(is.na(validation$validation_set$regex))
+  expect_equivalent(validation$validation_set[["values"]] %>% unlist(), c("1-bcd-345", "5-jdo-903"))
   expect_true(is.na(validation$validation_set$all_passed))
   expect_true(is.na(validation$validation_set$n))
   expect_true(is.na(validation$validation_set$n_passed))
@@ -787,8 +766,7 @@ test_that("Creating a `col_vals_regex()` step is possible", {
   expect_equivalent(validation$col_names, c("date_time", "date", "a", "b", "c", "d", "e", "f"))
   expect_equivalent(validation$validation_set$assertion_type, "col_vals_regex")
   expect_equivalent(validation$validation_set$column, "b")
-  expect_true(is.na(validation$validation_set$value))
-  expect_equivalent(validation$validation_set$regex, "[0-9]-.*")
+  expect_equivalent(validation$validation_set[["values"]] %>% unlist(), "[0-9]-.*")
   expect_true(is.na(validation$validation_set$all_passed))
   expect_true(is.na(validation$validation_set$n))
   expect_true(is.na(validation$validation_set$n_passed))
@@ -832,8 +810,7 @@ test_that("Creating a `col_vals_null()` step is possible", {
   expect_equivalent(validation$col_names, c("date_time", "date", "a", "b", "c", "d", "e", "f"))
   expect_equivalent(validation$validation_set$assertion_type, "col_vals_null")
   expect_equivalent(validation$validation_set$column, "b")
-  expect_true(is.na(validation$validation_set$value))
-  expect_true(is.na(validation$validation_set$regex))
+  expect_true(is.null(validation$validation_set[["values"]][[1]]))
   expect_true(is.na(validation$validation_set$all_passed))
   expect_true(is.na(validation$validation_set$n))
   expect_true(is.na(validation$validation_set$n_passed))
@@ -877,8 +854,7 @@ test_that("Creating a `col_vals_not_null()` step is possible", {
   expect_equivalent(validation$col_names, c("date_time", "date", "a", "b", "c", "d", "e", "f"))
   expect_equivalent(validation$validation_set$assertion_type, "col_vals_not_null")
   expect_equivalent(validation$validation_set$column, "b")
-  expect_true(is.na(validation$validation_set$value))
-  expect_true(is.na(validation$validation_set$regex))
+  expect_true(is.null(validation$validation_set[["values"]][[1]]))
   expect_true(is.na(validation$validation_set$all_passed))
   expect_true(is.na(validation$validation_set$n))
   expect_true(is.na(validation$validation_set$n_passed))
@@ -922,8 +898,7 @@ test_that("Creating a `rows_distinct()` step is possible", {
   expect_equivalent(validation$col_names, c("date_time", "date", "a", "b", "c", "d", "e", "f"))
   expect_equivalent(validation$validation_set$assertion_type, "rows_distinct")
   expect_true(is.na(validation$validation_set$column %>% .[[1]] %>% .[[1]]))
-  expect_true(is.na(validation$validation_set$value))
-  expect_true(is.na(validation$validation_set$regex))
+  expect_true(is.null(validation$validation_set[["values"]][[1]]))
   expect_true(is.na(validation$validation_set$all_passed))
   expect_true(is.na(validation$validation_set$n))
   expect_true(is.na(validation$validation_set$n_passed))
